@@ -575,6 +575,7 @@ left."
 
 (define-derived-mode ement-taxy-mode magit-section-mode "Ement-Taxy"
   :global nil
+  ;; FIXME: Initialize `ement-room-list-timestamp-colors' here.
   (setq-local bookmark-make-record-function #'ement-taxy-bookmark-make-record
               revert-buffer-function #'ement-taxy-revert))
 
@@ -588,11 +589,15 @@ left."
   (when (and ement-taxy-auto-update
              (buffer-live-p (get-buffer "*Ement Taxy*")))
     (with-current-buffer (get-buffer "*Ement Taxy*")
-      ;; FIXME: This seems to redisplay the buffer even when it's buried.  But it
-      ;; shouldn't, because the revert function uses `display-buffer-no-window'.  But it
-      ;; doesn't always happen; it only seems to in certain circumstances, e.g. when the
-      ;; minibuffer is open, which should be unrelated to this.
-      (revert-buffer))))
+      (unless (region-active-p)
+        ;; Don't refresh the list if the region is active (e.g. if the user is trying to
+        ;; operate on multiple rooms).
+
+        ;; FIXME: This seems to redisplay the buffer even when it's buried.  But it
+        ;; shouldn't, because the revert function uses `display-buffer-no-window'.  But it
+        ;; doesn't always happen; it only seems to in certain circumstances, e.g. when the
+        ;; minibuffer is open, which should be unrelated to this.
+        (revert-buffer)))))
 
 ;;;; Footer
 
